Reads the value of a matrix parameter for the current step. Matrix steps
receive DAGGLE_MATRIX_<KEY> environment variables with the key uppercased.
Reads the value of a matrix parameter for the current step. Matrix steps
receive DAGGLE_MATRIX_<KEY> environment variables with the key uppercased.